function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useState } from 'react';
import { StyleSheet, TouchableOpacity, View, Dimensions, Animated, Easing, ScrollView } from 'react-native';
import { Text } from 'react-native-elements';
import * as Colors from './utils/Colors';
import * as Style from './utils/Style';
import TimePicker from './TimePicker';
import { parseDateToCalendarFormat } from './utils/DateUtils';
import { Status } from './utils/Status';
import CalendarWithTimer from './CalendarWithTimer';
const {
  height
} = Dimensions.get('window');

const ModalBottomSheet = params => {
  const animatedValue = new Animated.Value(0);
  const [startDate, setStartDate] = useState(parseDateToCalendarFormat(params.startDate));
  const [endDate, setEndDate] = useState(parseDateToCalendarFormat(params.endDate));
  const [isStartDateSelected, setIsStartDateSelected] = useState(true);
  const [isEndDateSelected, setIsEndDateSelected] = useState(false);
  /* let currentTime = new Date();
  let currentHourRaw = currentTime.getHours();
  let currentHour = currentHourRaw > 12 ? currentHourRaw - 12 : currentHourRaw;
  let currentMinutes = currentTime.getMinutes();
  let currentTimeAmPm = currentTime.getHours() >= 12 ? 'PM' : 'AM'; */

  /* const [startTime, setStartTime] = useState<Time>({
    hour: currentHour,
    minutes: currentMinutes,
    amPm: currentTimeAmPm,
  });
    const [endTime, setEndTime] = useState<Time>({
    hour: currentHour,
    minutes: currentMinutes,
    amPm: currentTimeAmPm,
  }); */

  /*  const [updatedStartTime, setUpdatedStartTime] = useState<Time>({
    hour: currentHour,
    minutes: currentMinutes,
    amPm: currentTimeAmPm,
  });
  const [updatedEndTime, setUpdatedEndTime] = useState<Time>({
    hour: currentHour,
    minutes: currentMinutes,
    amPm: currentTimeAmPm,
  });
  */

  const [updatedStartTime, setUpdatedStartTime] = useState(params === null || params === void 0 ? void 0 : params.startTime);
  const [updatedEndTime, setUpdatedEndTime] = useState(params === null || params === void 0 ? void 0 : params.endTime);
  React.useEffect(() => {
    Animated.timing(animatedValue, {
      toValue: 1,
      duration: 600,
      easing: Easing.linear,
      useNativeDriver: true
    }).start();
  }, [params.openBottomSheet]);

  const onDoneSelect = () => {
    params.onDoneSelect(startDate, endDate, updatedStartTime, updatedEndTime);
  };

  const onTimeSelect = (hour, minutes, amPm) => {
    if (isEndDateSelected) {
      setUpdatedEndTime({
        hour: hour,
        minutes: minutes,
        amPm: amPm
      });
      params.onEndTimeSelect(hour + ':' + minutes + ' ' + amPm);
    } else {
      setUpdatedStartTime({
        hour: hour,
        minutes: minutes,
        amPm: amPm
      });
      params.onStartTimeSelect(hour + ':' + minutes + ' ' + amPm);
    }
  };

  const onStartEndChanged = type => {
    setIsStartDateSelected(type == 1);
    setIsEndDateSelected(type == 2);

    if (type == 2) {
      params === null || params === void 0 ? void 0 : params.setEndTime(updatedEndTime);
    } else {
      params === null || params === void 0 ? void 0 : params.setStartTime(updatedStartTime);
    }
  };

  function Header() {
    return /*#__PURE__*/React.createElement(View, {
      style: styles.header
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.view
    }), /*#__PURE__*/React.createElement(View, {
      style: {
        flex: 1,
        flexDirection: 'row',
        marginTop: 10,
        marginHorizontal: 4,
        alignItems: 'baseline',
        justifyContent: 'space-between'
      }
    }, /*#__PURE__*/React.createElement(Text, {
      style: [Style.styleSheet.boldText]
    }, "Date & Time"), /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: onDoneSelect
    }, /*#__PURE__*/React.createElement(Text, {
      style: [Style.styleSheet.headerTextStyle, {
        color: Colors.PrimaryColor,
        alignSelf: 'flex-end'
      }]
    }, "Done"))));
  }

  return params.openBottomSheet == true || params.openBottomSheet == false ? /*#__PURE__*/React.createElement(Animated.View, {
    style: {
      flex: 1,
      backgroundColor: 'white',
      alignItems: 'stretch',
      height: height - 200,
      borderTopLeftRadius: 15,
      borderTopRightRadius: 15,
      elevation: 10,
      paddingVertical: 0.0,
      paddingHorizontal: 10.0,
      transform: [params.openBottomSheet == true ? {
        translateY: animatedValue.interpolate({
          inputRange: [0, 1],
          outputRange: [700, 0]
        })
      } : params.openBottomSheet == false ? {
        translateY: animatedValue.interpolate({
          inputRange: [0, 1],
          outputRange: [0, 800]
        })
      } : null]
    }
  }, /*#__PURE__*/React.createElement(Header, null), /*#__PURE__*/React.createElement(ScrollView, null, /*#__PURE__*/React.createElement(CalendarWithTimer, _extends({}, params, {
    onStartEndChanged: onStartEndChanged,
    onStartDateSelect: day => {
      setStartDate(day);
      params.onStartDateSelect(day);
    },
    onEndDateSelect: day => {
      setEndDate(day);
      params.onEndDateSelect(day);
    }
  })), isStartDateSelected ? /*#__PURE__*/React.createElement(TimePicker, {
    key: `StartTime_${params === null || params === void 0 ? void 0 : params.startTime}`,
    dateForTime: startDate,
    timeSelectionType: Status.DEFAULT,
    startTime: params === null || params === void 0 ? void 0 : params.startTime,
    onTimeSelected: onTimeSelect
  }) : /*#__PURE__*/React.createElement(TimePicker, {
    key: `EndTime_${params === null || params === void 0 ? void 0 : params.endTime}`,
    dateForTime: startDate,
    timeSelectionType: Status.PREVIOUSDISABLED,
    startTime: params === null || params === void 0 ? void 0 : params.endTime,
    onTimeSelected: onTimeSelect
  }))) : null;
};

const styles = StyleSheet.create({
  bottomSheetStyle: {
    flex: 1,
    backgroundColor: 'white',
    alignItems: 'stretch',
    height: height - 200,
    borderTopLeftRadius: 15,
    borderTopRightRadius: 15,
    elevation: 10,
    paddingVertical: 0.0,
    paddingHorizontal: 10.0
  },
  container: {
    flex: 1,
    backgroundColor: Colors.Grey
  },
  header: {
    height: 60
  },
  view: {
    alignSelf: 'center',
    marginTop: 8,
    width: 45,
    height: 6,
    borderRadius: 5,
    backgroundColor: Colors.LightGrey
  }
});
export default ModalBottomSheet;
//# sourceMappingURL=ModalBottomSheet.js.map